@@ -1,67 +1,42 @@
 package Chart::Clicker::Data::Range;
-use strict;
-use warnings;
+use Moose;
 
+has 'lower' => ( is => 'rw', isa => 'Num' );
+has 'upper' => ( is => 'rw', isa => 'Num' );
+has 'min' => ( is => 'rw', isa => 'Num' );
+has 'max' => ( is => 'rw', isa => 'Num' );
 
-use base 'Class::Accessor::Fast';
-__PACKAGE__->mk_accessors(qw(lower upper min max));
-
-sub new {
-    my $proto = shift();
-    my $self = $proto->SUPER::new(@_);
-
-    if(defined($self->min())) {
-        $self->lower($self->min());
-    }
-
-    if(defined($self->max())) {
-        $self->upper($self->max());
-    }
-
-    return $self;
-}
-
-sub lower {
+after 'lower' => sub {
     my $self = shift();
 
-    if(@_) {
-        unless(defined($self->min())) {
-            $self->_lower_accessor(@_);
-        }
+    if($self->{'min'}) {
+        $self->{'lower'} = $self->{'min'};
     }
-    return $self->_lower_accessor();
-}
+};
 
-sub min {
+after 'upper' => sub {
     my $self = shift();
 
-    if(@_) {
-        $self->_min_accessor(@_);
-        $self->_lower_accessor($self->_min_accessor());
+    if($self->{'max'}) {
+        $self->{'upper'} = $self->{'max'};
     }
-    return $self->_min_accessor();
-}
+};
 
-sub upper {
+after 'min' => sub {
     my $self = shift();
 
-    if(@_) {
-        unless(defined($self->max())) {
-            $self->_upper_accessor(@_);
-        }
+    if($self->{'min'}) {
+        $self->{'lower'} = $self->{'min'};
     }
-    return $self->_upper_accessor();
-}
+};
 
-sub max {
+after 'max' => sub {
     my $self = shift();
 
-    if(@_) {
-        $self->_max_accessor(@_);
-        $self->_upper_accessor($self->_max_accessor());
+    if($self->{'max'}) {
+        $self->{'upper'} = $self->{'max'};
     }
-    return $self->_max_accessor();
-}
+};
 
 sub span {
     my $self = shift();
@@ -88,6 +63,21 @@ sub combine {
     return 1;
 }
 
+sub add {
+    my $self = shift();
+    my $range = shift();
+
+    if(defined($self->upper())) {
+        $self->upper($self->upper() + $range->upper());
+    } else {
+        $self->upper($range->upper());
+    }
+
+    if(!defined($self->lower()) || ($range->lower() < $self->lower())) {
+        $self->lower($range->lower());
+    }
+}
+
 sub divvy {
     my $self = shift();
     my $n = shift();
@@ -136,7 +126,7 @@ Creates a new, empty Series
 
 Set/Get the lower bound for this Range
 
-=item
+=item min
 
 Set/Get the minimum value allowed for this Range.  This value should only be
 set if you want to EXPLICITLY set the lower value.
@@ -159,6 +149,11 @@ Returns the span of this range, or UPPER - LOWER.
 Combine this range with the specified so that this range encompasses the
 values specified.
 
+=item add
+
+Adds the specified range to this one.  The lower is reduced to that of the
+provided one if it is lower, and the upper is ADDED to this range's upper.
+
 =item divvy
 
   my $values = $range->divvy(5);
