@@ -1,16 +1,27 @@
 package Chart::Clicker::Renderer::Bar;
-use strict;
-use warnings;
+use Moose;
 
-use Chart::Clicker::Renderer::Base;
-use base 'Chart::Clicker::Renderer::Base';
+extends 'Chart::Clicker::Renderer::Base';
 
 sub prepare {
     my $self = shift();
 
     $self->SUPER::prepare(@_);
 
-    $self->{'COUNT'}++;
+    my $clicker = shift();
+    my $idim = shift();
+    my $datasets = shift();
+
+    foreach my $ds (@{ $datasets }) {
+        if(!defined($self->{'KEYCOUNT'})) {
+            $self->{'KEYCOUNT'} = $ds->max_key_count();
+        } else {
+            if($self->{'KEYCOUNT'} < $ds->max_key_count()) {
+                $self->{'KEYCOUNT'} = $ds->max_key_count();
+            }
+        }
+    }
+
     $self->{'SCOUNT'} = 1;
 
     return 1;
@@ -27,8 +38,8 @@ sub draw {
     my $height = $self->height();
     my $width = $self->width();
 
-    my $xper = $domain->per();
-    my $yper = $range->per();
+    # my $xper = $domain->per();
+    # my $yper = $range->per();
 
     my @vals = @{ $series->values() };
     my @keys = @{ $series->keys() };
@@ -40,15 +51,18 @@ sub draw {
         $padding = 1;
     }
 
-    # Calculate the bar width we can use to fit all the datasets.
-    #my $bwidth = ($xper * $self->{'COUNT'}) - $padding;
-    my $bwidth = ($width / scalar(@vals)) / $self->dataset_count();
+    my $xper = $self->width() / ($self->{'KEYCOUNT'});
 
-    for(0..($series->key_count() - 1)) {
+    # Calculate the bar width we can use to fit all the datasets.
+    my $bwidth = int(($width / scalar(@vals)) / $self->dataset_count());
+
+    my $sksent = $series->key_count() - 1;
+    for(0..$sksent) {
         # Add the series_count times the width to so that each bar
         # gets rendered with it's partner in the other series.
-        my $x = $domain->mark($keys[$_]) + ($self->{'SCOUNT'} * $bwidth);
-        my $y = $height - $range->mark($vals[$_]);
+         #my $x = $domain->mark($keys[$_]) + ($self->{'SCOUNT'} * $bwidth);
+        my $x = ($xper * ($keys[$_] - $domain->range->lower())) + ($self->{'SCOUNT'} * $bwidth);
+        my $y = int($height - $range->mark($vals[$_]));
         $cr->rectangle(
             $x + $padding / 2, $y,
             - $bwidth, $height,
@@ -64,6 +78,9 @@ sub draw {
         $fillcolor = $color;
     }
 
+    $cr->set_source_rgba($fillcolor->rgba());
+    $cr->fill_preserve();
+
     my $stroke = $self->get_option('stroke');
     if(defined($stroke)) {
         my $linewidth = $stroke->width();
@@ -74,10 +91,6 @@ sub draw {
         $cr->stroke();
     }
 
-    my $path = $cr->copy_path();
-    $cr->append_path($path);
-    $cr->set_source_rgba($fillcolor->rgba());
-    $cr->fill();
     $self->{'SCOUNT'}++;
 
     return 1;
@@ -102,6 +115,10 @@ Chart::Clicker::Renderer::Bar renders a dataset as points.
 
 =over 4
 
+=item stroke
+
+A stroke to use on each bar.
+
 =item opacity
 
 If true this value will be used when setting the opacity of the bar's fill.
